##  Using the Dashboard
  * Monitor KPIs: Track KPIs for AI agents to understand the status of your AI agent inventory. These KPIs are also displayed on the architecture executive dashboard. To learn how to use the dashboard and drill down to KPI data, see [Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "The architecture executive dashboard provides essential KPIs related to the organization’s IT landscape, enabling informed, data-driven decision-making through valuable insights.").
  * View discovered AI agents: Check the status of discovered AI agents and navigate to the AI agent discovery inbox directly from the dashboard.
  * Navigate to saved searches and AI agent fact sheets: Quickly access saved searches for AI agents and navigate to recently updated AI agent fact sheets.
  * Preview reports for AI agents: View dedicated reports for AI agents and navigate to them from the dashboard for a more detailed analysis.


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
